@@ -122,7 +122,7 @@ class PMA_Theme
      *
      * @param string $folder path to theme
      *
-     * @return object PMA_Theme
+     * @return PMA_Theme|false
      * @static
      * @access public
      */
@@ -333,61 +333,6 @@ class PMA_Theme
         }
     }
 
-    /**
-     * Builds a CSS rule used for html formatted SQL queries
-     *
-     * @param string $classname The class name
-     * @param string $property  The property name
-     * @param string $value     The property value
-     *
-     * @return string  The CSS rule
-     *
-     * @access public
-     *
-     * @see    PMA_SQP_buildCssData()
-     */
-    public function buildSQPCssRule($classname, $property, $value)
-    {
-        $str     = '.' . $classname . ' {';
-        if ($value != '') {
-            $str .= $property . ': ' . $value . ';';
-        }
-        $str     .= '}' . "\n";
-
-        return $str;
-    } // end of the "PMA_SQP_buildCssRule()" function
-
-
-    /**
-     * Builds CSS rules used for html formatted SQL queries
-     *
-     * @return string  The CSS rules set
-     *
-     * @access public
-     *
-     * @global array   The current PMA configuration
-     *
-     * @see    PMA_SQP_buildCssRule()
-     */
-    public function buildSQPCssData()
-    {
-        global $cfg;
-
-        $css_string     = '';
-        foreach ($cfg['SQP']['fmtColor'] AS $key => $col) {
-            $css_string .= $this->buildSQPCssRule('syntax_' . $key, 'color', $col);
-        }
-
-        for ($i = 0; $i < 8; $i++) {
-            $css_string .= $this->buildSQPCssRule(
-                'syntax_indent' . $i, 'margin-left',
-                ($i * $cfg['SQP']['fmtInd']) . $cfg['SQP']['fmtIndUnit']
-            );
-        }
-
-        return $css_string;
-    } // end of the "PMA_SQP_buildCssData()" function
-
     /**
      * load css (send to stdout, normally the browser)
      *
@@ -398,8 +343,6 @@ class PMA_Theme
     {
         $success = true;
 
-        echo $this->buildSQPCssData();
-
         if ($GLOBALS['text_dir'] === 'ltr') {
             $right = 'right';
             $left = 'left';
@@ -438,7 +381,7 @@ class PMA_Theme
     public function getPrintPreview()
     {
         $url_params = array('set_theme' => $this->getId());
-        $url = 'index.php'. PMA_generate_common_url($url_params);
+        $url = 'index.php'. PMA_URL_getCommon($url_params);
 
         $retval  = '<div class="theme_preview">';
         $retval .= '<h2>';
@@ -538,64 +481,5 @@ class PMA_Theme
         }
         return implode("\n", $result);
     }
-
-    /**
-     * Returns CSS styles for CodeMirror editor based on query formatter colors.
-     *
-     * @return string CSS code.
-     */
-    function getCssCodeMirror()
-    {
-        if (! $GLOBALS['cfg']['CodemirrorEnable']) {
-            return '';
-        }
-
-        $result[] = 'span.cm-keyword, span.cm-statement-verb {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_reservedWord'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-variable {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_identifier'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-comment {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['comment'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-mysql-string {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['quote'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-operator {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['punct'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-mysql-word {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_identifier'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-builtin {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_functionName'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-variable-2 {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_columnType'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-variable-3 {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['alpha_columnAttrib'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-separator {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['punct'] . ';';
-        $result[] = '}';
-        $result[] = 'span.cm-number {';
-        $result[] = '    color: '
-            . $GLOBALS['cfg']['SQP']['fmtColor']['digit_integer'] . ';';
-        $result[] = '}';
-
-        return implode("\n", $result);
-    }
 }
 ?>
